package xyz.lychee.lagfixer.libs.adventure.text;

import java.util.Objects;
import java.util.stream.Stream;
import xyz.lychee.lagfixer.libs.adventure.internal.Internals;
import xyz.lychee.lagfixer.libs.annotations.NotNull;
import xyz.lychee.lagfixer.libs.annotations.Nullable;
import xyz.lychee.lagfixer.libs.examination.ExaminableProperty;

final class TranslationArgumentImpl implements TranslationArgument {
   private static final Component TRUE = Component.text("true");
   private static final Component FALSE = Component.text("false");
   private final Object value;

   TranslationArgumentImpl(final Object value) {
      this.value = value;
   }

   public @NotNull Object value() {
      return this.value;
   }

   public @NotNull Component asComponent() {
      if (this.value instanceof Component) {
         return (Component)this.value;
      } else if (this.value instanceof Boolean) {
         return (Boolean)this.value ? TRUE : FALSE;
      } else {
         return Component.text(String.valueOf(this.value));
      }
   }

   public boolean equals(final @Nullable Object other) {
      if (this == other) {
         return true;
      } else if (other != null && this.getClass() == other.getClass()) {
         TranslationArgumentImpl that = (TranslationArgumentImpl)other;
         return Objects.equals(this.value, that.value);
      } else {
         return false;
      }
   }

   public int hashCode() {
      return Objects.hash(new Object[]{this.value});
   }

   public String toString() {
      return Internals.toString(this);
   }

   public @NotNull Stream<? extends ExaminableProperty> examinableProperties() {
      return Stream.of(ExaminableProperty.of("value", this.value));
   }
}
